Struct CentralHeaderVersion
struct CentralHeaderVersion
use this to mark extra fields specified in the central header
Implementations
impl Clone for CentralHeaderVersion
fn clone(self: &Self) -> CentralHeaderVersion
impl Debug for CentralHeaderVersion
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl ExtraFieldVersion for CentralHeaderVersion
impl Freeze for CentralHeaderVersion
impl RefUnwindSafe for CentralHeaderVersion
impl Send for CentralHeaderVersion
impl Sync for CentralHeaderVersion
impl Unpin for CentralHeaderVersion
impl UnsafeUnpin for CentralHeaderVersion
impl UnwindSafe for CentralHeaderVersion
impl<T> Any for CentralHeaderVersion
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CentralHeaderVersion
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CentralHeaderVersion
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for CentralHeaderVersion
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for CentralHeaderVersion
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Same for CentralHeaderVersion
impl<T> ToOwned for CentralHeaderVersion
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for CentralHeaderVersion
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CentralHeaderVersion
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CentralHeaderVersion
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>