Struct LocalHeaderVersion

struct LocalHeaderVersion

use this to mark extra fields specified in a local header

Implementations

impl Clone for LocalHeaderVersion

fn clone(self: &Self) -> LocalHeaderVersion

impl Debug for LocalHeaderVersion

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl ExtraFieldVersion for LocalHeaderVersion

impl Freeze for LocalHeaderVersion

impl RefUnwindSafe for LocalHeaderVersion

impl Send for LocalHeaderVersion

impl Sync for LocalHeaderVersion

impl Unpin for LocalHeaderVersion

impl UnsafeUnpin for LocalHeaderVersion

impl UnwindSafe for LocalHeaderVersion

impl<T> Any for LocalHeaderVersion

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for LocalHeaderVersion

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for LocalHeaderVersion

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for LocalHeaderVersion

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for LocalHeaderVersion

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for LocalHeaderVersion

impl<T> ToOwned for LocalHeaderVersion

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for LocalHeaderVersion

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for LocalHeaderVersion

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for LocalHeaderVersion

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>