FileOptions

Struct FileOptions 

#[non_exhaustive]
pub struct FileOptions<'k, T: FileOptionExtension> { /* private fields */ }
Metadata for a file to be written

Implementations

Source

impl<T: FileOptionExtension> FileOptions<'_, T>

pub const fn has_encryption(&self) -> bool

Indicates whether this file will be encrypted (whether with AES or ZipCrypto).

pub const fn compression_method(self, method: CompressionMethod) -> Self

Set the compression method for the new file

The default is CompressionMethod::Deflated if it is enabled. If not, CompressionMethod::Bzip2 is the default if it is enabled. If neither bzip2 nor deflate is enabled, CompressionMethod::Stored becomes the default and files are written uncompressed.

pub const fn system(self, system: System) -> Self

Set the system field for the new file

If not set, the zip crate will use the current system

pub const fn compression_level(self, level: Option<i64>) -> Self

Set the compression level for the new file

None value specifies default compression level.

Range of values depends on compression method:

  • Deflated: 10 - 264 for Zopfli, 0 - 9 for other encoders. Default is 24 if Zopfli is the only encoder, or 6 otherwise.
  • Bzip2: 0 - 9. Default is 6
  • Zstd: -7 - 22, with zero being mapped to default level. Default is 3
  • others: only None is allowed
pub const fn last_modified_time(self, mod_time: DateTime) -> Self

Set the last modified time

The default is the current timestamp if the ‘time’ feature is enabled, and 1980-01-01 otherwise

pub const fn unix_permissions(self, mode: u32) -> Self

Set the permissions for the new file.

The format is represented with unix-style permissions. The default is 0o644, which represents rw-r--r-- for files, and 0o755, which represents rwxr-xr-x for directories.

This method only preserves the file permissions bits (via a & 0o777) and discards higher file mode bits. So it cannot be used to denote an entry as a directory, symlink, or other special file type.

pub const fn large_file(self, large: bool) -> Self

Set whether the new file’s compressed and uncompressed size is less than 4 GiB.

If set to false and the file exceeds the limit, an I/O error is thrown and the file is aborted. If set to true, readers will require ZIP64 support and if the file does not exceed the limit, 20 B are wasted. The default is false.

pub fn with_aes_encryption_and_salt( self, password: &[u8], salt: AesSalt, ) -> FileOptions<'_, T>

Available on crate feature aes-crypto only.

Set the AES encryption parameters. The salt must be at least 8 bytes long for AES-128, and at least 16 bytes long for AES-256. This method is not recommended, since having a fixed salt is not secure. Consider using with_aes_encryption instead, which uses a random salt and is more secure.

pub fn with_aes_encryption( self, mode: AesMode, password: &str, ) -> FileOptions<'_, T>

Available on crate feature aes-crypto only.

Set the AES encryption parameters.

pub fn with_aes_encryption_bytes( self, mode: AesMode, password: &[u8], ) -> FileOptions<'_, T>

Available on crate feature aes-crypto only.

Set the AES encryption parameters.

pub const fn with_zopfli_buffer(self, size: Option<usize>) -> Self

Available on crate feature deflate-zopfli only.

Sets the size of the buffer used to hold the next block that Zopfli will compress. The larger the buffer, the more effective the compression, but the more memory is required. A value of None indicates no buffer, which is recommended only when all non-empty writes are larger than about 32 KiB.

pub const fn get_compression_level(&self) -> Option<i64>

Returns the compression level currently set.

pub const fn with_alignment(self, alignment: u16) -> Self

Sets the alignment to the given number of bytes.

Source

impl FileOptions<'_, ExtendedFileOptions>

pub fn with_file_comment<S: Into<Box<str>>>(self, comment: S) -> Self

Set the file comment.

pub fn add_extra_data<D: AsRef<[u8]>>( &mut self, header_id: u16, data: D, central_only: bool, ) -> ZipResult<()>

Adds an extra data field.

pub fn clear_extra_data(self) -> Self

Removes the extra data fields.

Source

impl FileOptions<'static, ()>

pub const DEFAULT: Self

Constructs a const FileOptions object.

Note: This value is different than the return value of FileOptions::default():

  • The last_modified_time is DateTime::DEFAULT. This corresponds to 1980-01-01 00:00:00
Source

impl<'k> FileOptions<'k, ()>

pub fn into_full_options(self) -> FullFileOptions<'k>

Convert to FullFileOptions.