Struct Ntfs
struct Ntfs { ... }
The NTFS extra field as described in PKWARE's APPNOTE.TXT v6.3.9.
This field stores Windows file times, which are 64-bit unsigned integer values that represents the number of 100-nanosecond intervals that have elapsed since "1601-01-01 00:00:00 UTC".
Implementations
impl Ntfs
fn try_from_reader<R>(reader: &mut R, len: u16) -> ZipResult<Self> where R: ReadCreates a NTFS extra field struct by reading the required bytes from the reader.
This method assumes that the length has already been read, therefore it must be passed as an argument.
fn mtime(self: &Self) -> u64Returns the file last modification time as a file time.
fn atime(self: &Self) -> u64Returns the file last access time as a file time.
fn ctime(self: &Self) -> u64Returns the file creation time as a file time.
impl Clone for Ntfs
fn clone(self: &Self) -> Ntfs
impl Debug for Ntfs
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Ntfs
impl RefUnwindSafe for Ntfs
impl Send for Ntfs
impl Sync for Ntfs
impl Unpin for Ntfs
impl UnsafeUnpin for Ntfs
impl UnwindSafe for Ntfs
impl<T> Any for Ntfs
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Ntfs
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Ntfs
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Ntfs
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Ntfs
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Same for Ntfs
impl<T> ToOwned for Ntfs
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Ntfs
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Ntfs
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Ntfs
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>